@@ -9,6 +9,7 @@
 
 pub mod parsers;
 
+use std::borrow::Cow;
 use std::collections::HashMap;
 use std::fmt;
 
@@ -45,7 +46,7 @@ use std::fmt;
 /// The Vector of command line arguments presented to the executable in `std::env::args().collect()` is used to define the `Command` struct fields.
 ///
 /// See the documentation for the `Command` struct methods and fields to learn how to use the parsed data in your command line interface application logic.
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, PartialEq)]
 pub struct Command {
     /// Vector of ordered command line arguments
     pub argv: Vec<String>,
@@ -61,8 +62,8 @@ pub struct Command {
     pub first_arg: Option<String>,
     /// `Option<String>` of last positional argument to the executable. `None` if there are no arguments to the executable.
     pub last_arg: Option<String>,
-    /// `Option<Vec<String>>` of ordered arguments that follow a double dash command line idiom. `None` if a double dash argument is not present or there are no arguments after the double dash argument.
-    pub double_dash_argv: Option<Vec<String>>,
+    /// `Option<Vec<String>>` of ordered arguments that follow a double hyphen command line idiom. `None` if a double hyphen argument is not present or there are no arguments after the double hyphen argument.
+    pub double_hyphen_argv: Option<Vec<String>>,
 }
 
 // Traits
@@ -111,7 +112,7 @@ impl Command {
         let definitions_hm = parsers::parse_definitions(&arguments);
         let first_arg_definition = parsers::parse_first_arg(&arguments);
         let last_arg_definition = parsers::parse_last_arg(&arguments);
-        let double_dash_definition = parsers::parse_double_dash_args(&arguments);
+        let double_hyphen_definition = parsers::parse_double_hyphen_args(&arguments);
 
         Command {
             argv: arguments_definition,
@@ -121,7 +122,7 @@ impl Command {
             definitions: definitions_hm,
             first_arg: first_arg_definition,
             last_arg: last_arg_definition,
-            double_dash_argv: double_dash_definition,
+            double_hyphen_argv: double_hyphen_definition,
         }
     }
 
@@ -166,10 +167,28 @@ impl Command {
         !self.definitions.is_empty()
     }
 
+    /// Returns a boolean for the question "Does the command include any arguments following the double hyphen (--) idiom?"
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let c = commandlines::Command::new();
+    ///
+    /// if c.has_double_hyphen_args() {
+    ///     // arguments were identified following a double hyphen idiom
+    /// }
+    /// ```
+    pub fn has_double_hyphen_args(&self) -> bool {
+        match &self.double_hyphen_argv {
+            Some(_) => true,
+            None => false,
+        }
+    }
+
     /// Returns a boolean for the question "Does the command include any multi-option short syntax style option arguments?"
     ///
     /// # Remarks
-    /// POSIX defines a short option style that uses a single dash delimiter with more than one option indicated by the individual characters defined in the argument string (e.g., `-hij` means that the command has the options `-h -i -j`).  This method provides support for determining whether a mops style option is present in the command string.
+    /// POSIX defines a short option style that uses a single hyphen delimiter with more than one option indicated by the individual characters defined in the argument string (e.g., `-hij` means that the command has the options `-h -i -j`).  This method provides support for determining whether a mops style option is present in the command string.
     ///
     /// # Examples
     ///
@@ -245,7 +264,7 @@ impl Command {
     /// Returns a boolean for the question "Does the command include the option `needle` when the POSIX multi-option short syntax option style is used?"
     ///
     /// # Remarks
-    /// The mops style defined by POSIX includes a single dash character followed by one or more alphanumeric characters in the Unicode Basic Latin set.  Each character represents a unique option switch.  For example, "-lmn" is used to indicate "-l -m -n".  This method tests against any short option formatted argument included in the command irrespective of the number of alphanumeric characters that are included.  The method does not test against long options (i.e., those that begin with two dashes).
+    /// The mops style defined by POSIX includes a single hyphen character followed by one or more alphanumeric characters in the Unicode Basic Latin set.  Each character represents a unique option switch.  For example, "-lmn" is used to indicate "-l -m -n".  This method tests against any short option formatted argument included in the command irrespective of the number of alphanumeric characters that are included.  The method does not test against long options (i.e., those that begin with two hyphens).
     ///
     /// If you do not use the mops option syntax in your application, use the `Command::contains_option()` method instead.
     ///
@@ -283,7 +302,7 @@ impl Command {
     /// Returns a boolean for the question "Does the command include the option `needle` when the POSIX multi-option short syntax option style is used?"
     ///
     /// # Remarks
-    /// The mops style defined by POSIX includes a single dash character followed by one or more alphanumeric characters in the Unicode Basic Latin set.  Each character represents a unique option switch.  For example, "-lmn" is used to indicate "-l -m -n".  This method tests against any short option formatted argument included in the command irrespective of the number of alphanumeric characters that are included.  The method does not test against long options (i.e., those that begin with two dashes).
+    /// The mops style defined by POSIX includes a single hyphen character followed by one or more alphanumeric characters in the Unicode Basic Latin set.  Each character represents a unique option switch.  For example, "-lmn" is used to indicate "-l -m -n".  This method tests against any short option formatted argument included in the command irrespective of the number of alphanumeric characters that are included.  The method does not test against long options (i.e., those that begin with two hyphens).
     ///
     /// If you do not use the mops option syntax in your application, use the `Command::contains_all_options()` method instead.
     ///
@@ -325,7 +344,7 @@ impl Command {
     /// ```
     pub fn contains_all_options(&self, needle_vec: Vec<&str>) -> bool {
         for needle in needle_vec {
-            if !self.options.contains(&needle.to_string()) {
+            if !self.options.contains(&String::from(needle)) {
                 return false;
             }
         }
@@ -335,7 +354,7 @@ impl Command {
     /// Returns a boolean for the question "Does the command include the option `needle` when the POSIX multi-option short syntax option style is used?"
     ///
     /// # Remarks
-    /// The mops style defined by POSIX includes a single dash character followed by one or more alphanumeric characters in the Unicode Basic Latin set.  Each character represents a unique option switch.  For example, "-lmn" is used to indicate "-l -m -n".  This method tests against any short option formatted argument included in the command irrespective of the number of alphanumeric characters that are included.  The method does not test against long options (i.e., those that begin with two dashes).
+    /// The mops style defined by POSIX includes a single hyphen character followed by one or more alphanumeric characters in the Unicode Basic Latin set.  Each character represents a unique option switch.  For example, "-lmn" is used to indicate "-l -m -n".  This method tests against any short option formatted argument included in the command irrespective of the number of alphanumeric characters that are included.  The method does not test against long options (i.e., those that begin with two hyphens).
     ///
     /// If you do not use the mops option syntax in your application, use the `Command::contains_any_options()` method instead.
     ///
@@ -376,7 +395,7 @@ impl Command {
     /// ```
     pub fn contains_any_option(&self, needle_vec: Vec<&str>) -> bool {
         for needle in needle_vec {
-            if self.options.contains(&needle.to_string()) {
+            if self.options.contains(&String::from(needle)) {
                 return true;
             }
         }
@@ -394,6 +413,7 @@ impl Command {
     ///     // the command sequence was identified as "[executable] filter help"
     /// }
     /// ```
+    #[cfg_attr(feature = "cargo-clippy", allow(needless_pass_by_value))]
     pub fn contains_sequence(&self, needle_vec: Vec<&str>) -> bool {
         // confirm that the request does not exceed the length of arguments in the command
         // subtract value of 1 for the executable which is excluded in this test
@@ -409,7 +429,7 @@ impl Command {
         true
     }
 
-    /// Returns Option<&String> definition for a key defined by `needle`
+    /// Returns `Option<Cow<str>>` definition for a key defined by `needle`
     ///
     /// Returns `None` if the option was not used in the command
     ///
@@ -421,15 +441,19 @@ impl Command {
     /// let c = commandlines::Command::new();
     ///
     /// match c.get_definition_for("--name") {
-    ///     Some(x) => println!("The definition for --name is {}", *x),
+    ///     Some(x) => println!("The definition for --name is {}", x),
     ///     None => eprintln!("Missing")
     /// };
     /// ```
-    pub fn get_definition_for(&self, needle: &str) -> Option<&String> {
-        self.definitions.get(&String::from(needle))
+    pub fn get_definition_for(&self, needle: &str) -> Option<Cow<str>> {
+        if let Some(x) = self.definitions.get(&String::from(needle)) {
+            return Some(Cow::Borrowed(x));
+        }
+
+        None
     }
 
-    /// Returns `Option<&String>` for argument at index position `i+1` for `needle` at index position `i`
+    /// Returns `Option<Cow<str>>` for argument at index position `i+1` for `needle` at index position `i`
     ///
     /// Returns `None` if `needle` is the last positional argument in the command
     ///
@@ -445,21 +469,59 @@ impl Command {
     /// let c = commandlines::Command::new();
     ///
     /// match c.get_argument_after("-o") {
-    ///     Some(x) => println!("The filepath definition after -o is {}", *x),
+    ///     Some(x) => println!("The filepath definition after -o is {}", x),
     ///     None => eprintln!("-o is the last positional argument in the command")
     /// }
     /// ```
-    pub fn get_argument_after(&self, needle: &str) -> Option<&String> {
+    pub fn get_argument_after(&self, needle: &str) -> Option<Cow<str>> {
         for (index, value) in self.argv.iter().enumerate() {
             if value == needle {
-                return self.argv.get(index + 1);
+                if let Some(x) = self.argv.get(index + 1) {
+                    return Some(Cow::Borrowed(x));
+                }
             }
         }
 
         None
     }
 
-    /// Returns `Option<&String>` for the argument at index position `needle`
+    /// Returns `Option<Vec<Cow<str>>>` for the one or more ordered arguments that follow the `needle` argument
+    ///
+    /// Returns `None` if `needle` is not in the command or there are no arguments after the `needle` argument
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let c = commandlines::Command::new();
+    ///
+    /// match c.get_arguments_after("-o") {
+    ///     Some(x) => println!("The arguments after the -o option are {:?}", x),
+    ///     None => eprintln!("-o not found or there were no arguments after -o")
+    /// }
+    /// ```
+    pub fn get_arguments_after(&self, needle: &str) -> Option<Vec<Cow<str>>> {
+        for (index, value) in self.argv.iter().enumerate() {
+            // test for presence of needle in argv vector
+            if value == needle {
+                // if found, confirm that there is at least one arg after
+                if self.argv.get(index + 1).is_some() {
+                    // make a new Vec<Cow<str>> to fill with arg strings for return to calling code
+                    // and fill with the arguments, maintaining valid sequence of arguments
+                    let mut v: Vec<Cow<str>> = Vec::new();
+                    for arg in &self.argv[(index + 1)..] {
+                        v.push(Cow::Borrowed(arg));
+                    }
+                    return Some(v);
+                } else {
+                    return None;
+                }
+            }
+        }
+
+        None
+    }
+
+    /// Returns `Option<Cow<str>>` for the argument at index position `needle`
     ///
     /// Returns `None` if `needle` is outside of the bounds of valid index values
     ///
@@ -470,17 +532,103 @@ impl Command {
     /// let c = commandlines::Command::new();
     ///
     /// match c.get_argument_at(0) {
-    ///     Some(x) => println!("The executable is {}", *x),
+    ///     Some(x) => println!("The executable is {}", x),
     ///     None => eprintln!("Error")
     /// }
     ///
     /// match c.get_argument_at(1) {
-    ///     Some(x) => println!("The first positional argument is {}", *x),
+    ///     Some(x) => println!("The first positional argument is {}", x),
     ///     None => eprintln!("There is no first positional argument")
     /// }
     /// ```
-    pub fn get_argument_at(&self, needle: usize) -> Option<&String> {
-        self.argv.get(needle)
+    pub fn get_argument_at(&self, needle: usize) -> Option<Cow<str>> {
+        if let Some(x) = self.argv.get(needle) {
+            return Some(Cow::Borrowed(x));
+        }
+
+        None
+    }
+
+    /// Returns `Option<Vec<Cow<str>>>` for the arguments in sequence that follow a double hyphen `--` command line idiom
+    ///
+    /// Returns `None` if there is no double hyphen idiom or there are no arguments that follow the idiom
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let c = commandlines::Command::new();
+    ///
+    /// match c.get_arguments_after_double_hyphen() {
+    ///     Some(x) => println!("Args following double hyphen: {:?}", x),
+    ///     None => eprintln!("There are no arguments that follow a double hyphen idiom")
+    /// }
+    /// ```
+    pub fn get_arguments_after_double_hyphen(&self) -> Option<Vec<Cow<str>>> {
+        if let Some(x) = &self.double_hyphen_argv {
+            let mut v: Vec<Cow<str>> = Vec::new();
+            for arg in x {
+                v.push(Cow::Borrowed(arg))
+            }
+            return Some(v);
+        }
+
+        None
+    }
+
+    /// Returns `Option<Cow<str>>` for the first positional argument to the executable
+    ///
+    /// Returns `None` if there are no arguments to the executable
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let c = commandlines::Command::new();
+    ///
+    /// match c.get_argument_first() {
+    ///     Some(x) => println!("The first positional argument is {}", x),
+    ///     None => eprintln!("There are no arguments to the executable")
+    /// }
+    /// ```
+    pub fn get_argument_first(&self) -> Option<Cow<str>> {
+        match &self.first_arg {
+            Some(x) => Some(Cow::Borrowed(x)),
+            None => None,
+        }
+    }
+
+    /// Returns `Option<Cow<str>>` for the last positional argument to the executable
+    ///
+    /// Returns `None` if there are no arguments to the executable
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let c = commandlines::Command::new();
+    ///
+    /// match c.get_argument_last() {
+    ///     Some(x) => println!("The last positional argument is {}", x),
+    ///     None => eprintln!("There are no arguments to the executable")
+    /// }
+    /// ```
+    pub fn get_argument_last(&self) -> Option<Cow<str>> {
+        match &self.last_arg {
+            Some(x) => Some(Cow::Borrowed(x)),
+            None => None,
+        }
+    }
+
+    /// Returns `Cow<str>` for the executable
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let c = commandlines::Command::new();
+    ///
+    /// println!("{} v1.0.0", c.get_executable())
+    ///
+    /// ```
+    pub fn get_executable(&self) -> Cow<str> {
+        Cow::Borrowed(&self.executable)
     }
 
     /// Returns `Option<usize>` for index position of the argument `needle` in the `Command.argv` Vector
@@ -554,6 +702,15 @@ impl Command {
 mod tests {
     use super::*;
 
+    #[test]
+    fn command_instantiation_partial_eq() {
+        let c1 = Command::new_with_vec(vec!["test".to_string(), "arg".to_string()]);
+        let c2 = Command::new_with_vec(vec!["test".to_string(), "arg".to_string()]);
+        let c3 = Command::new_with_vec(vec!["test".to_string(), "else".to_string()]);
+        assert!(c1 == c2);
+        assert!(c1 != c3);
+    }
+
     #[test]
     fn command_instantiation_environment_args_test() {
         let c = Command::new();
@@ -645,7 +802,7 @@ mod tests {
     }
 
     #[test]
-    fn command_instantiation_double_dash_argv() {
+    fn command_instantiation_double_hyphen_argv() {
         let c = Command::new_with_vec(vec![
             "test".to_string(),
             "--something".to_string(),
@@ -656,11 +813,11 @@ mod tests {
             "lastpos".to_string(),
         ]);
         let expected_vec = vec![String::from("--double"), String::from("lastpos")];
-        assert_eq!(c.double_dash_argv, Some(expected_vec));
+        assert_eq!(c.double_hyphen_argv, Some(expected_vec));
     }
 
     #[test]
-    fn command_instantiation_double_dash_argv_no_args() {
+    fn command_instantiation_double_hyphen_argv_no_args() {
         let c = Command::new_with_vec(vec![
             "test".to_string(),
             "--something".to_string(),
@@ -668,18 +825,18 @@ mod tests {
             "--another=otherdef".to_string(),
             "--".to_string(),
         ]);
-        assert_eq!(c.double_dash_argv, None);
+        assert_eq!(c.double_hyphen_argv, None);
     }
 
     #[test]
-    fn command_instantiation_double_dash_argv_no_double_dash() {
+    fn command_instantiation_double_hyphen_argv_no_double_hyphen() {
         let c = Command::new_with_vec(vec![
             "test".to_string(),
             "--something".to_string(),
             "--option=define".to_string(),
             "--another=otherdef".to_string(),
         ]);
-        assert_eq!(c.double_dash_argv, None);
+        assert_eq!(c.double_hyphen_argv, None);
     }
 
     #[test]
@@ -712,6 +869,30 @@ mod tests {
         assert_eq!(c.has_definitions(), false);
     }
 
+    #[test]
+    fn command_method_has_double_hyphen_args() {
+        let c1 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "-o".to_string(),
+            "--".to_string(),
+            "arg1".to_string(),
+            "--arg2".to_string(),
+        ]);
+        let c2 =
+            Command::new_with_vec(vec!["test".to_string(), "-o".to_string(), "--".to_string()]);
+        let c3 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "-o".to_string(),
+            "--test".to_string(),
+            "arg1".to_string(),
+            "--arg2".to_string(),
+        ]);
+
+        assert_eq!(c1.has_double_hyphen_args(), true);
+        assert_eq!(c2.has_double_hyphen_args(), false);
+        assert_eq!(c3.has_double_hyphen_args(), false);
+    }
+
     #[test]
     fn command_has_mops_true() {
         let c = Command::new_with_vec(vec![
@@ -809,9 +990,9 @@ mod tests {
         ]);
         assert_eq!(c.contains_mops("-o"), false);
         assert_eq!(c.contains_mops("-a"), false);
-        assert_eq!(c.contains_mops("-h"), false); // should ignore all options after a double dash idiom
-        assert_eq!(c.contains_mops("-i"), false); // should ignore all options after a double dash idiom
-        assert_eq!(c.contains_mops("-j"), false); // should ignore all options after a double dash idiom
+        assert_eq!(c.contains_mops("-h"), false); // should ignore all options after a double hyphen idiom
+        assert_eq!(c.contains_mops("-i"), false); // should ignore all options after a double hyphen idiom
+        assert_eq!(c.contains_mops("-j"), false); // should ignore all options after a double hyphen idiom
     }
 
     #[test]
@@ -960,7 +1141,7 @@ mod tests {
 
         assert_eq!(
             c.get_definition_for("--option"),
-            Some(&String::from("definition"))
+            Some(Cow::Borrowed("definition"))
         );
     }
 
@@ -983,7 +1164,7 @@ mod tests {
             "path".to_string(),
         ]);
 
-        assert_eq!(c.get_argument_after("-o"), Some(&String::from("path")));
+        assert_eq!(c.get_argument_after("-o"), Some(Cow::Borrowed("path")));
     }
 
     #[test]
@@ -1000,15 +1181,139 @@ mod tests {
         assert_eq!(c.get_argument_after("bogus"), None);
     }
 
+    #[test]
+    fn command_method_get_arguments_after() {
+        let c1 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "-o".to_string(),
+            "path1".to_string(),
+        ]);
+
+        let c2 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "-o".to_string(),
+            "path1".to_string(),
+            "path2".to_string(),
+        ]);
+
+        let c3 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "-o".to_string(),
+            "--out".to_string(),
+            "--other".to_string(),
+        ]);
+
+        let c4 = Command::new_with_vec(vec!["test".to_string(), "-o".to_string()]);
+
+        let c1_exp = Some(vec![Cow::Borrowed("path1")]);
+        let c2_exp = Some(vec![Cow::Borrowed("path1"), Cow::Borrowed("path2")]);
+        let c3_exp = Some(vec![Cow::Borrowed("--out"), Cow::Borrowed("--other")]);
+
+        assert_eq!(c1.get_arguments_after("-o"), c1_exp); // collects single non-option arg
+        assert_eq!(c2.get_arguments_after("-o"), c2_exp); // collects multiple non-option args
+        assert_eq!(c3.get_arguments_after("-o"), c3_exp); // collects option args
+        assert_eq!(c4.get_arguments_after("-o"), None); // missing args after request
+        assert_eq!(c1.get_arguments_after("--bogus"), None); // invalid request (not present in command)
+    }
+
     #[test]
     fn command_method_get_argument_at() {
         let c = Command::new_with_vec(vec!["test".to_string(), "-o".to_string()]);
 
-        assert_eq!(c.get_argument_at(0), Some(&String::from("test"))); // zero indexed request
-        assert_eq!(c.get_argument_at(1), Some(&String::from("-o"))); // valid index
+        assert_eq!(c.get_argument_at(0), Some(Cow::Borrowed("test"))); // zero indexed request
+        assert_eq!(c.get_argument_at(1), Some(Cow::Borrowed("-o"))); // valid index
         assert_eq!(c.get_argument_at(10), None); // invalid index
     }
 
+    #[test]
+    fn command_method_get_arguments_after_double_hyphen() {
+        let c1 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "-o".to_string(),
+            "--".to_string(),
+            "--after1".to_string(),
+            "--after2".to_string(),
+            "path".to_string(),
+        ]);
+        let c2 =
+            Command::new_with_vec(vec!["test".to_string(), "-o".to_string(), "--".to_string()]);
+        let c3 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "-o".to_string(),
+            "--after1".to_string(),
+            "--after2".to_string(),
+        ]);
+
+        let c1_exp = Some(vec![
+            Cow::Borrowed("--after1"),
+            Cow::Borrowed("--after2"),
+            Cow::Borrowed("path"),
+        ]);
+
+        assert_eq!(c1.get_arguments_after_double_hyphen(), c1_exp);
+        assert_eq!(c2.get_arguments_after_double_hyphen(), None);
+        assert_eq!(c3.get_arguments_after_double_hyphen(), None);
+    }
+
+    #[test]
+    fn command_method_get_argument_first() {
+        let c1 = Command::new_with_vec(vec!["test".to_string(), "-o".to_string()]);
+        let c2 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "-o".to_string(),
+            "more".to_string(),
+        ]);
+        let c3 = Command::new_with_vec(vec!["test".to_string(), "first".to_string()]);
+        let c4 = Command::new_with_vec(vec!["test".to_string(), "--help".to_string()]);
+        let c5 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "--help".to_string(),
+            "more".to_string(),
+        ]);
+        let c6 = Command::new_with_vec(vec!["test".to_string()]);
+
+        assert_eq!(c1.get_argument_first(), Some(Cow::Borrowed("-o"))); // short option
+        assert_eq!(c2.get_argument_first(), Some(Cow::Borrowed("-o"))); // short option with additional args
+        assert_eq!(c3.get_argument_first(), Some(Cow::Borrowed("first"))); // subcommand style argument
+        assert_eq!(c4.get_argument_first(), Some(Cow::Borrowed("--help"))); // long option
+        assert_eq!(c5.get_argument_first(), Some(Cow::Borrowed("--help"))); // long option with additional args
+        assert_eq!(c6.get_argument_first(), None);
+    }
+
+    #[test]
+    fn command_method_get_argument_last() {
+        let c1 = Command::new_with_vec(vec!["test".to_string(), "-o".to_string()]);
+        let c2 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "-o".to_string(),
+            "more".to_string(),
+        ]);
+        let c3 = Command::new_with_vec(vec!["test".to_string(), "first".to_string()]);
+        let c4 = Command::new_with_vec(vec!["test".to_string(), "--help".to_string()]);
+        let c5 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "--help".to_string(),
+            "more".to_string(),
+        ]);
+        let c6 = Command::new_with_vec(vec!["test".to_string()]);
+
+        assert_eq!(c1.get_argument_last(), Some(Cow::Borrowed("-o"))); // short option
+        assert_eq!(c2.get_argument_last(), Some(Cow::Borrowed("more"))); // short option followed by LP arg
+        assert_eq!(c3.get_argument_last(), Some(Cow::Borrowed("first"))); // subcommand style argument
+        assert_eq!(c4.get_argument_last(), Some(Cow::Borrowed("--help"))); // long option
+        assert_eq!(c5.get_argument_last(), Some(Cow::Borrowed("more"))); // long option followed by LP arg
+        assert_eq!(c1.get_argument_last(), Some(Cow::Borrowed("-o")));
+        assert_eq!(c6.get_argument_last(), None);
+    }
+
+    #[test]
+    fn command_method_get_executable() {
+        let c1 = Command::new_with_vec(vec!["test".to_string(), "-o".to_string()]);
+        let c2 = Command::new_with_vec(vec!["~/user/path/to/test".to_string(), "-o".to_string()]);
+        assert_eq!(c1.get_executable(), Cow::Borrowed("test"));
+        assert_eq!(c2.get_executable(), Cow::Borrowed("~/user/path/to/test"));
+    }
+
     #[test]
     fn command_method_get_index_of() {
         let c = Command::new_with_vec(vec!["test".to_string(), "-o".to_string()]);
